/**
 * Copyright (C) 2011 Brian Ferris <bdferris@onebusaway.org>
 * Copyright (C) 2011 Google, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onebusaway.siri.core.handlers;

import java.io.Reader;
import java.io.Writer;

/**
 * This method provides low-level access to a SIRI endpoint, appropriate for
 * implementing methods that expose the SIRI endpoint over a transport mechanism
 * (eg. an HTTP server).
 * 
 * @author bdferris
 * 
 */
public interface SiriRawHandler {

  /**
   * Handle an incoming raw request, in the form of a {@link Reader} typically
   * containing a SIRI message in XML form. Any response will be written to the
   * outgoing {@link Writer}.
   * 
   * @param reader the input reader
   * @param writer the output writer
   */
  public void handleRawRequest(Reader reader, Writer writer);
}
